@@ -453,7 +453,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
         currentIM = self.ImConfig.getCurrentInputMethod()
 
         # find out about the other options
-        names = dict(xim=_('none'), ibus='IBus', scim='SCIM', hangul='Hangul', thai='Thai')
+        names = dict(none=_('none'), xim='XIM', ibus='IBus', scim='SCIM', hangul='Hangul', thai='Thai')
         for (i, IM) in enumerate(self.ImConfig.getAvailableInputMethods()):
             name = names[IM] if IM in names else IM
             iter = model.append()
